@@ -6,7 +6,6 @@
  */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
 
 class QCheckBox;
@@ -15,11 +14,7 @@ class PIMContactsRunnerConfig : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit PIMContactsRunnerConfig(QWidget *parent, const QVariantList &args);
-#else
-    explicit PIMContactsRunnerConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
-#endif
+    explicit PIMContactsRunnerConfig(QObject *parent, const KPluginMetaData &data);
 
 public Q_SLOTS:
     void save() override;
